const R = require('ramda');


/**
 * getNewKey :: Object -> String -> String
 */
const getNewKey = R.curry((table, key) =>
    R.pathOr(key, [key, 'id'], table));


/**
 * mapKeys :: (String -> String) -> Object -> Object
 *
 * https://github.com/ramda/ramda/wiki/Cookbook#map-keys-of-an-object
 */
const mapKeys = R.curry((fn, obj) =>
    R.fromPairs(R.map(R.adjust(fn, 0), R.toPairs(obj))));


/**
 * mapFields :: WebappFieldMap -> Object -> Object
 *
 * @param webappInfo
 * @param dataIn
 */
const mapFields = R.curry((webappFieldMap, dataIn) =>
    mapKeys(getNewKey(webappFieldMap), dataIn)
);


/**
 * extractCombinedFieldMap :: CommonConfigFile -> singleWebappConfig -> CombinedFieldMap
 *
 */
const extractCombinedFieldMap = R.curry((commonConfigFile, singleWebappConfig) => {
    const commonMap = commonConfigFile.commonFieldsMap,
          appMap = singleWebappConfig.fieldMap;

    return R.merge(commonMap, appMap);
});


module.exports = {
    getNewKey,
    mapKeys,
    mapFields,
    extractCombinedFieldMap
};